import sys
import json
import os
from typing import Dict, List, Optional
from PyQt6.QtWidgets import (QApplication, QMainWindow, QWidget, QVBoxLayout, QHBoxLayout, 
                             QComboBox, QPushButton, QTextEdit, QLabel, QGroupBox, 
                             QTabWidget, QLineEdit, QListWidget, QFormLayout, QGridLayout, QScrollArea, QMessageBox)
from PyQt6.QtCore import Qt

class PortraitConfig:
    def __init__(self):
        self.options_file = "portrait_options_extended.json"
        self.translations_file = "translations.json"
        self.options = self.load_options()
        self.translations = self.load_translations()

    def load_options(self) -> Dict[str, List[str]]:
        if not os.path.exists(self.options_file):
            QMessageBox.critical(None, "Fehler", f"Die Datei '{self.options_file}' wurde im Stammverzeichnis nicht gefunden. Bitte stelle sicher, dass sie vorhanden ist.")
            sys.exit(1)
        with open(self.options_file, "r", encoding="utf-8") as f:
            return json.load(f)

    def load_translations(self) -> Dict[str, Dict[str, str]]:
        if not os.path.exists(self.translations_file):
            QMessageBox.critical(None, "Fehler", f"Die Datei '{self.translations_file}' wurde im Stammverzeichnis nicht gefunden. Bitte stelle sicher, dass sie vorhanden ist.")
            sys.exit(1)
        with open(self.translations_file, "r", encoding="utf-8") as f:
            return json.load(f)

class PortraitGenerator(QMainWindow):
    def __init__(self):
        super().__init__()
        self.config = PortraitConfig()
        self.language = "Deutsch"  # Standard: Deutsch
        self.settings = {}  # Speicher für Benutzereinstellungen
        self.init_ui()

    def init_ui(self):
        self.setWindowTitle(self.config.translations[self.language]["title"])
        self.setGeometry(100, 100, 1400, 900)

        main_widget = QWidget(self)
        self.setCentralWidget(main_widget)
        layout = QVBoxLayout(main_widget)

        self.tabs = QTabWidget()
        layout.addWidget(self.tabs)

        self.tab1 = QWidget()
        self.tabs.addTab(self.tab1, self.config.translations[self.language]["tab1"])
        self.init_tab1()

        self.tab2 = QWidget()
        self.tabs.addTab(self.tab2, self.config.translations[self.language]["tab2"])
        self.init_tab2()

        self.tab3 = QWidget()
        self.tabs.addTab(self.tab3, self.config.translations[self.language]["tab3"])
        self.init_tab3()

    def init_tab1(self):
        layout = QVBoxLayout(self.tab1)

        # Sprachauswahl
        lang_layout = QHBoxLayout()
        lang_label = QLabel("Sprache / Language:")
        self.lang_combo = QComboBox()
        self.lang_combo.addItems(list(self.config.translations.keys()))
        self.lang_combo.setCurrentText(self.language)
        self.lang_combo.currentTextChanged.connect(self.change_language)
        lang_layout.addWidget(lang_label)
        lang_layout.addWidget(self.lang_combo)
        layout.addLayout(lang_layout)

        # Scrollbereich
        scroll = QScrollArea()
        scroll_widget = QWidget()
        scroll_layout = QGridLayout(scroll_widget)
        scroll.setWidget(scroll_widget)
        scroll.setWidgetResizable(True)
        layout.addWidget(scroll)

        # GUI-Elemente mit "Ja/Nein"-Optionen
        self.location_combo = QComboBox()
        self.location_combo.addItems([self.config.translations[self.language]["studio"], self.config.translations[self.language]["outdoor"]])
        self.location_combo.currentTextChanged.connect(self.update_location_options)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["location"]), 0, 0)
        scroll_layout.addWidget(self.location_combo, 0, 1)

        self.type_combo = QComboBox()
        self.type_combo.addItems([self.get_language_text(item) for item in self.config.options["portrait_types"]])
        self.type_include = QComboBox()
        self.type_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.type_combo.currentTextChanged.connect(self.update_type_options)
        self.type_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["type"]), 1, 0)
        scroll_layout.addWidget(self.type_combo, 1, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 1, 2)
        scroll_layout.addWidget(self.type_include, 1, 3)

        self.success_combo = QComboBox()
        self.success_include = QComboBox()
        self.success_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.success_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.success_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["success"]), 2, 0)
        scroll_layout.addWidget(self.success_combo, 2, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 2, 2)
        scroll_layout.addWidget(self.success_include, 2, 3)

        self.nationality_input = QLineEdit()
        self.nationality_include = QComboBox()
        self.nationality_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.nationality_input.textChanged.connect(self.update_prompt_preview)
        self.nationality_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["nationality"]), 3, 0)
        scroll_layout.addWidget(self.nationality_input, 3, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 3, 2)
        scroll_layout.addWidget(self.nationality_include, 3, 3)

        self.role_combo = QComboBox()
        self.role_include = QComboBox()
        self.role_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.role_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.role_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["role"]), 4, 0)
        scroll_layout.addWidget(self.role_combo, 4, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 4, 2)
        scroll_layout.addWidget(self.role_include, 4, 3)

        self.gender_combo = QComboBox()
        self.gender_combo.addItems(["Männlich", "Weiblich"] if self.language == "Deutsch" else ["Male", "Female"])
        self.gender_combo.currentTextChanged.connect(self.update_clothing_options)
        self.gender_combo.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["gender"]), 5, 0)
        scroll_layout.addWidget(self.gender_combo, 5, 1)

        self.age_combo = QComboBox()
        self.age_include = QComboBox()
        self.age_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.age_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.age_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["age_range"]), 6, 0)
        scroll_layout.addWidget(self.age_combo, 6, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 6, 2)
        scroll_layout.addWidget(self.age_include, 6, 3)

        self.camera_type_combo = QComboBox()
        self.camera_type_include = QComboBox()
        self.camera_type_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.camera_type_combo.currentTextChanged.connect(self.update_camera_options)
        self.camera_type_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["camera_type"]), 7, 0)
        scroll_layout.addWidget(self.camera_type_combo, 7, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 7, 2)
        scroll_layout.addWidget(self.camera_type_include, 7, 3)

        self.camera_combo = QComboBox()
        self.camera_include = QComboBox()
        self.camera_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.camera_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.camera_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["camera"]), 8, 0)
        scroll_layout.addWidget(self.camera_combo, 8, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 8, 2)
        scroll_layout.addWidget(self.camera_include, 8, 3)

        self.lens_combo = QComboBox()
        self.lens_include = QComboBox()
        self.lens_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.lens_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.lens_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["lens"]), 9, 0)
        scroll_layout.addWidget(self.lens_combo, 9, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 9, 2)
        scroll_layout.addWidget(self.lens_include, 9, 3)

        self.film_combo = QComboBox()
        self.film_include = QComboBox()
        self.film_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.film_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.film_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["film"]), 10, 0)
        scroll_layout.addWidget(self.film_combo, 10, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 10, 2)
        scroll_layout.addWidget(self.film_include, 10, 3)

        self.film_detail_combo = QComboBox()
        self.film_detail_include = QComboBox()
        self.film_detail_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.film_detail_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.film_detail_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["film_detail"]), 11, 0)
        scroll_layout.addWidget(self.film_detail_combo, 11, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 11, 2)
        scroll_layout.addWidget(self.film_detail_include, 11, 3)

        self.quality_combo = QComboBox()
        self.quality_include = QComboBox()
        self.quality_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.quality_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.quality_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["quality"]), 12, 0)
        scroll_layout.addWidget(self.quality_combo, 12, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 12, 2)
        scroll_layout.addWidget(self.quality_include, 12, 3)

        self.subject_combo = QComboBox()
        self.subject_include = QComboBox()
        self.subject_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.subject_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.subject_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["traits"]), 13, 0)
        scroll_layout.addWidget(self.subject_combo, 13, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 13, 2)
        scroll_layout.addWidget(self.subject_include, 13, 3)

        self.subject_detail_combo = QComboBox()
        self.subject_detail_include = QComboBox()
        self.subject_detail_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.subject_detail_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.subject_detail_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["details"]), 14, 0)
        scroll_layout.addWidget(self.subject_detail_combo, 14, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 14, 2)
        scroll_layout.addWidget(self.subject_detail_include, 14, 3)

        self.style_combo = QComboBox()
        self.style_include = QComboBox()
        self.style_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.style_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.style_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["style"]), 15, 0)
        scroll_layout.addWidget(self.style_combo, 15, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 15, 2)
        scroll_layout.addWidget(self.style_include, 15, 3)

        self.clothing_combo = QComboBox()
        self.clothing_include = QComboBox()
        self.clothing_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.clothing_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.clothing_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["clothing"]), 16, 0)
        scroll_layout.addWidget(self.clothing_combo, 16, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 16, 2)
        scroll_layout.addWidget(self.clothing_include, 16, 3)

        self.cultural_combo = QComboBox()
        self.cultural_include = QComboBox()
        self.cultural_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.cultural_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.cultural_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["cultural_element"]), 17, 0)
        scroll_layout.addWidget(self.cultural_combo, 17, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 17, 2)
        scroll_layout.addWidget(self.cultural_include, 17, 3)

        self.time_period_combo = QComboBox()
        self.time_period_include = QComboBox()
        self.time_period_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.time_period_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.time_period_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["time_period"]), 18, 0)
        scroll_layout.addWidget(self.time_period_combo, 18, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 18, 2)
        scroll_layout.addWidget(self.time_period_include, 18, 3)

        self.pose_combo = QComboBox()
        self.pose_include = QComboBox()
        self.pose_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.pose_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.pose_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["pose"]), 19, 0)
        scroll_layout.addWidget(self.pose_combo, 19, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 19, 2)
        scroll_layout.addWidget(self.pose_include, 19, 3)

        self.lighting_combo = QComboBox()
        self.lighting_include = QComboBox()
        self.lighting_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.lighting_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.lighting_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["lighting"]), 20, 0)
        scroll_layout.addWidget(self.lighting_combo, 20, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 20, 2)
        scroll_layout.addWidget(self.lighting_include, 20, 3)

        self.background_combo = QComboBox()
        self.background_include = QComboBox()
        self.background_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.background_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.background_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["background"]), 21, 0)
        scroll_layout.addWidget(self.background_combo, 21, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 21, 2)
        scroll_layout.addWidget(self.background_include, 21, 3)

        self.props_combo = QComboBox()
        self.props_include = QComboBox()
        self.props_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.props_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.props_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["prop"]), 22, 0)
        scroll_layout.addWidget(self.props_combo, 22, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 22, 2)
        scroll_layout.addWidget(self.props_include, 22, 3)

        self.ambiance_combo = QComboBox()
        self.ambiance_include = QComboBox()
        self.ambiance_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.ambiance_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.ambiance_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["ambiance"]), 23, 0)
        scroll_layout.addWidget(self.ambiance_combo, 23, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 23, 2)
        scroll_layout.addWidget(self.ambiance_include, 23, 3)

        self.weather_combo = QComboBox()
        self.weather_include = QComboBox()
        self.weather_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.weather_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.weather_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["weather"]), 24, 0)
        scroll_layout.addWidget(self.weather_combo, 24, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 24, 2)
        scroll_layout.addWidget(self.weather_include, 24, 3)

        self.emotion_combo = QComboBox()
        self.emotion_include = QComboBox()
        self.emotion_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.emotion_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.emotion_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["emotion"]), 25, 0)
        scroll_layout.addWidget(self.emotion_combo, 25, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 25, 2)
        scroll_layout.addWidget(self.emotion_include, 25, 3)

        self.post_processing_choice_combo = QComboBox()
        self.post_processing_choice_combo.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.post_processing_choice_combo.currentTextChanged.connect(self.update_post_processing_options)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["post_processing_choice"]), 26, 0)
        scroll_layout.addWidget(self.post_processing_choice_combo, 26, 1)

        self.post_processing_combo = QComboBox()
        self.post_processing_include = QComboBox()
        self.post_processing_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.post_processing_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.post_processing_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["post_processing"]), 27, 0)
        scroll_layout.addWidget(self.post_processing_combo, 27, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 27, 2)
        scroll_layout.addWidget(self.post_processing_include, 27, 3)

        self.effect_combo = QComboBox()
        self.effect_include = QComboBox()
        self.effect_include.addItems([self.config.translations[self.language]["yes"], self.config.translations[self.language]["no"]])
        self.effect_combo.currentTextChanged.connect(self.update_prompt_preview)
        self.effect_include.currentTextChanged.connect(self.update_prompt_preview)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["effect"]), 28, 0)
        scroll_layout.addWidget(self.effect_combo, 28, 1)
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["include"]), 28, 2)
        scroll_layout.addWidget(self.effect_include, 28, 3)

        self.negative_prompt_input = QLineEdit()
        scroll_layout.addWidget(QLabel(self.config.translations[self.language]["negative_prompt"]), 29, 0)
        scroll_layout.addWidget(self.negative_prompt_input, 29, 1, 1, 3)

        # Live-Vorschau
        self.preview_text = QTextEdit()
        self.preview_text.setReadOnly(True)
        self.preview_text.setMaximumHeight(150)  # Korrigierte Zeile
        layout.addWidget(QLabel(self.config.translations[self.language]["preview"]))
        layout.addWidget(self.preview_text)

        # Tooltips setzen
        self.set_tooltips()

        # Generate Button
        generate_btn = QPushButton(self.config.translations[self.language]["generate"])
        generate_btn.clicked.connect(self.generate_prompt)
        layout.addWidget(generate_btn)

        self.populate_options()

    def init_tab2(self):
        layout = QVBoxLayout(self.tab2)
        layout.addWidget(QLabel(self.config.translations[self.language]["preview"]))
        self.prompt_text = QTextEdit()
        layout.addWidget(self.prompt_text)
        save_btn = QPushButton(self.config.translations[self.language]["save"])
        save_btn.clicked.connect(self.save_edited_prompt)
        layout.addWidget(save_btn)
        save_btn.setToolTip(self.config.translations[self.language]["tooltip_save"])

    def init_tab3(self):
        layout = QVBoxLayout(self.tab3)
        layout.addWidget(QLabel(self.config.translations[self.language]["edit_options"]))
        self.option_tabs = QTabWidget()
        layout.addWidget(self.option_tabs)

        for category in self.config.options.keys():
            if category in ["defaults", "camera_types_by_portrait_type"]:
                continue
            tab = QWidget()
            self.option_tabs.addTab(tab, category.capitalize())
            tab_layout = QVBoxLayout(tab)
            list_widget = QListWidget()
            if category in ["cameras", "films", "lenses"]:
                for subcat in self.config.options[category].keys():
                    for item in self.config.options[category][subcat]:
                        list_widget.addItem(f"{self.get_language_text(subcat)}: {self.get_language_text(item)}")
            else:
                list_widget.addItems([self.get_language_text(item) for item in self.config.options[category]])
            tab_layout.addWidget(list_widget)
            form_layout = QFormLayout()
            new_option_input = QLineEdit()
            form_layout.addRow(QLabel(self.config.translations[self.language]["add_new"].format(category=category)), new_option_input)
            if category in ["cameras", "films", "lenses"]:
                subcat_combo = QComboBox()
                subcat_combo.addItems([self.get_language_text(item) for item in self.config.options[category].keys()])
                form_layout.addRow(QLabel(self.config.translations[self.language]["subcategory"]), subcat_combo)
            add_btn = QPushButton(self.config.translations[self.language]["add_button"].format(category=category))
            add_btn.clicked.connect(lambda _, c=category, inp=new_option_input, sc=subcat_combo if category in ["cameras", "films", "lenses"] else None: self.add_option(c, inp.text(), sc.currentText() if sc else None))
            tab_layout.addLayout(form_layout)
            tab_layout.addWidget(add_btn)
        save_options_btn = QPushButton(self.config.translations[self.language]["save_options"])
        save_options_btn.clicked.connect(self.save_options)
        layout.addWidget(save_options_btn)

    def set_tooltips(self):
        self.location_combo.setToolTip(self.config.translations[self.language]["tooltip_location"])
        self.type_combo.setToolTip(self.config.translations[self.language]["tooltip_type"])
        self.success_combo.setToolTip(self.config.translations[self.language]["tooltip_success"])
        self.nationality_input.setToolTip(self.config.translations[self.language]["tooltip_nationality"])
        self.role_combo.setToolTip(self.config.translations[self.language]["tooltip_role"])
        self.gender_combo.setToolTip(self.config.translations[self.language]["tooltip_gender"])
        self.age_combo.setToolTip(self.config.translations[self.language]["tooltip_age"])
        self.camera_type_combo.setToolTip(self.config.translations[self.language]["tooltip_camera_type"])
        self.camera_combo.setToolTip(self.config.translations[self.language]["tooltip_camera"])
        self.lens_combo.setToolTip(self.config.translations[self.language]["tooltip_lens"])
        self.film_combo.setToolTip(self.config.translations[self.language]["tooltip_film"])
        self.film_detail_combo.setToolTip(self.config.translations[self.language]["tooltip_film_detail"])
        self.quality_combo.setToolTip(self.config.translations[self.language]["tooltip_quality"])
        self.subject_combo.setToolTip(self.config.translations[self.language]["tooltip_traits"])
        self.subject_detail_combo.setToolTip(self.config.translations[self.language]["tooltip_details"])
        self.style_combo.setToolTip(self.config.translations[self.language]["tooltip_style"])
        self.clothing_combo.setToolTip(self.config.translations[self.language]["tooltip_clothing"])
        self.cultural_combo.setToolTip(self.config.translations[self.language]["tooltip_cultural_element"])
        self.time_period_combo.setToolTip(self.config.translations[self.language]["tooltip_time_period"])
        self.pose_combo.setToolTip(self.config.translations[self.language]["tooltip_pose"])
        self.lighting_combo.setToolTip(self.config.translations[self.language]["tooltip_lighting"])
        self.background_combo.setToolTip(self.config.translations[self.language]["tooltip_background"])
        self.props_combo.setToolTip(self.config.translations[self.language]["tooltip_prop"])
        self.ambiance_combo.setToolTip(self.config.translations[self.language]["tooltip_ambiance"])
        self.weather_combo.setToolTip(self.config.translations[self.language]["tooltip_weather"])
        self.emotion_combo.setToolTip(self.config.translations[self.language]["tooltip_emotion"])
        self.post_processing_choice_combo.setToolTip(self.config.translations[self.language]["tooltip_post_processing_choice"])
        self.post_processing_combo.setToolTip(self.config.translations[self.language]["tooltip_post_processing"])
        self.effect_combo.setToolTip(self.config.translations[self.language]["tooltip_effect"])
        self.negative_prompt_input.setToolTip(self.config.translations[self.language]["tooltip_negative_prompt"])
        self.preview_text.setToolTip(self.config.translations[self.language]["tooltip_preview"])

    def save_settings(self):
        """Speichert die aktuellen Einstellungen der Widgets."""
        self.settings = {
            "location": self.location_combo.currentText(),
            "type": self.type_combo.currentText(),
            "type_include": self.type_include.currentText(),
            "success": self.success_combo.currentText(),
            "success_include": self.success_include.currentText(),
            "nationality": self.nationality_input.text(),
            "nationality_include": self.nationality_include.currentText(),
            "role": self.role_combo.currentText(),
            "role_include": self.role_include.currentText(),
            "gender": self.gender_combo.currentText(),
            "age": self.age_combo.currentText(),
            "age_include": self.age_include.currentText(),
            "camera_type": self.camera_type_combo.currentText(),
            "camera_type_include": self.camera_type_include.currentText(),
            "camera": self.camera_combo.currentText(),
            "camera_include": self.camera_include.currentText(),
            "lens": self.lens_combo.currentText(),
            "lens_include": self.lens_include.currentText(),
            "film": self.film_combo.currentText(),
            "film_include": self.film_include.currentText(),
            "film_detail": self.film_detail_combo.currentText(),
            "film_detail_include": self.film_detail_include.currentText(),
            "quality": self.quality_combo.currentText(),
            "quality_include": self.quality_include.currentText(),
            "subject": self.subject_combo.currentText(),
            "subject_include": self.subject_include.currentText(),
            "subject_detail": self.subject_detail_combo.currentText(),
            "subject_detail_include": self.subject_detail_include.currentText(),
            "style": self.style_combo.currentText(),
            "style_include": self.style_include.currentText(),
            "clothing": self.clothing_combo.currentText(),
            "clothing_include": self.clothing_include.currentText(),
            "cultural": self.cultural_combo.currentText(),
            "cultural_include": self.cultural_include.currentText(),
            "time_period": self.time_period_combo.currentText(),
            "time_period_include": self.time_period_include.currentText(),
            "pose": self.pose_combo.currentText(),
            "pose_include": self.pose_include.currentText(),
            "lighting": self.lighting_combo.currentText(),
            "lighting_include": self.lighting_include.currentText(),
            "background": self.background_combo.currentText(),
            "background_include": self.background_include.currentText(),
            "props": self.props_combo.currentText(),
            "props_include": self.props_include.currentText(),
            "ambiance": self.ambiance_combo.currentText(),
            "ambiance_include": self.ambiance_include.currentText(),
            "weather": self.weather_combo.currentText(),
            "weather_include": self.weather_include.currentText(),
            "emotion": self.emotion_combo.currentText(),
            "emotion_include": self.emotion_include.currentText(),
            "post_processing_choice": self.post_processing_choice_combo.currentText(),
            "post_processing": self.post_processing_combo.currentText(),
            "post_processing_include": self.post_processing_include.currentText(),
            "effect": self.effect_combo.currentText(),
            "effect_include": self.effect_include.currentText(),
            "negative_prompt": self.negative_prompt_input.text()
        }

    def restore_settings(self):
        """Stellt die gespeicherten Einstellungen wieder her."""
        if not self.settings:
            return

        self.location_combo.setCurrentText(self.settings.get("location", self.config.translations[self.language]["studio"]))
        self.type_combo.setCurrentText(self.settings.get("type", ""))
        self.type_include.setCurrentText(self.settings.get("type_include", self.config.translations[self.language]["yes"]))
        self.success_combo.setCurrentText(self.settings.get("success", ""))
        self.success_include.setCurrentText(self.settings.get("success_include", self.config.translations[self.language]["yes"]))
        self.nationality_input.setText(self.settings.get("nationality", ""))
        self.nationality_include.setCurrentText(self.settings.get("nationality_include", self.config.translations[self.language]["yes"]))
        self.role_combo.setCurrentText(self.settings.get("role", ""))
        self.role_include.setCurrentText(self.settings.get("role_include", self.config.translations[self.language]["yes"]))
        self.gender_combo.setCurrentText(self.settings.get("gender", "Männlich" if self.language == "Deutsch" else "Male"))
        self.age_combo.setCurrentText(self.settings.get("age", ""))
        self.age_include.setCurrentText(self.settings.get("age_include", self.config.translations[self.language]["yes"]))
        self.camera_type_combo.setCurrentText(self.settings.get("camera_type", ""))
        self.camera_type_include.setCurrentText(self.settings.get("camera_type_include", self.config.translations[self.language]["yes"]))
        self.camera_combo.setCurrentText(self.settings.get("camera", ""))
        self.camera_include.setCurrentText(self.settings.get("camera_include", self.config.translations[self.language]["yes"]))
        self.lens_combo.setCurrentText(self.settings.get("lens", ""))
        self.lens_include.setCurrentText(self.settings.get("lens_include", self.config.translations[self.language]["yes"]))
        self.film_combo.setCurrentText(self.settings.get("film", ""))
        self.film_include.setCurrentText(self.settings.get("film_include", self.config.translations[self.language]["yes"]))
        self.film_detail_combo.setCurrentText(self.settings.get("film_detail", ""))
        self.film_detail_include.setCurrentText(self.settings.get("film_detail_include", self.config.translations[self.language]["yes"]))
        self.quality_combo.setCurrentText(self.settings.get("quality", ""))
        self.quality_include.setCurrentText(self.settings.get("quality_include", self.config.translations[self.language]["yes"]))
        self.subject_combo.setCurrentText(self.settings.get("subject", ""))
        self.subject_include.setCurrentText(self.settings.get("subject_include", self.config.translations[self.language]["yes"]))
        self.subject_detail_combo.setCurrentText(self.settings.get("subject_detail", ""))
        self.subject_detail_include.setCurrentText(self.settings.get("subject_detail_include", self.config.translations[self.language]["yes"]))
        self.style_combo.setCurrentText(self.settings.get("style", ""))
        self.style_include.setCurrentText(self.settings.get("style_include", self.config.translations[self.language]["yes"]))
        self.clothing_combo.setCurrentText(self.settings.get("clothing", ""))
        self.clothing_include.setCurrentText(self.settings.get("clothing_include", self.config.translations[self.language]["yes"]))
        self.cultural_combo.setCurrentText(self.settings.get("cultural", ""))
        self.cultural_include.setCurrentText(self.settings.get("cultural_include", self.config.translations[self.language]["yes"]))
        self.time_period_combo.setCurrentText(self.settings.get("time_period", ""))
        self.time_period_include.setCurrentText(self.settings.get("time_period_include", self.config.translations[self.language]["yes"]))
        self.pose_combo.setCurrentText(self.settings.get("pose", ""))
        self.pose_include.setCurrentText(self.settings.get("pose_include", self.config.translations[self.language]["yes"]))
        self.lighting_combo.setCurrentText(self.settings.get("lighting", ""))
        self.lighting_include.setCurrentText(self.settings.get("lighting_include", self.config.translations[self.language]["yes"]))
        self.background_combo.setCurrentText(self.settings.get("background", ""))
        self.background_include.setCurrentText(self.settings.get("background_include", self.config.translations[self.language]["yes"]))
        self.props_combo.setCurrentText(self.settings.get("props", ""))
        self.props_include.setCurrentText(self.settings.get("props_include", self.config.translations[self.language]["yes"]))
        self.ambiance_combo.setCurrentText(self.settings.get("ambiance", ""))
        self.ambiance_include.setCurrentText(self.settings.get("ambiance_include", self.config.translations[self.language]["yes"]))
        self.weather_combo.setCurrentText(self.settings.get("weather", ""))
        self.weather_include.setCurrentText(self.settings.get("weather_include", self.config.translations[self.language]["yes"]))
        self.emotion_combo.setCurrentText(self.settings.get("emotion", ""))
        self.emotion_include.setCurrentText(self.settings.get("emotion_include", self.config.translations[self.language]["yes"]))
        self.post_processing_choice_combo.setCurrentText(self.settings.get("post_processing_choice", self.config.translations[self.language]["yes"]))
        self.post_processing_combo.setCurrentText(self.settings.get("post_processing", ""))
        self.post_processing_include.setCurrentText(self.settings.get("post_processing_include", self.config.translations[self.language]["yes"]))
        self.effect_combo.setCurrentText(self.settings.get("effect", ""))
        self.effect_include.setCurrentText(self.settings.get("effect_include", self.config.translations[self.language]["yes"]))
        self.negative_prompt_input.setText(self.settings.get("negative_prompt", ""))

    def change_language(self, lang: str):
        # Speichere die aktuellen Einstellungen vor dem Sprachwechsel
        self.save_settings()
        
        self.language = lang
        self.setWindowTitle(self.config.translations[lang]["title"])
        self.tabs.setTabText(0, self.config.translations[lang]["tab1"])
        self.tabs.setTabText(1, self.config.translations[lang]["tab2"])
        self.tabs.setTabText(2, self.config.translations[lang]["tab3"])
        self.block_signals(True)
        self.rebuild_tab1()
        self.rebuild_tab2()
        self.rebuild_tab3()
        self.block_signals(False)
        self.tabs.setCurrentIndex(0)
        
        # Stelle die gespeicherten Einstellungen wieder her
        self.restore_settings()
        self.update_prompt_preview()

    def block_signals(self, block: bool):
        for widget in self.tab1.findChildren(QComboBox):
            widget.blockSignals(block)

    def rebuild_tab1(self):
        self.tab1.deleteLater()
        self.tab1 = QWidget()
        self.tabs.insertTab(0, self.tab1, self.config.translations[self.language]["tab1"])
        self.init_tab1()

    def rebuild_tab2(self):
        self.tab2.deleteLater()
        self.tab2 = QWidget()
        self.tabs.insertTab(1, self.tab2, self.config.translations[self.language]["tab2"])
        self.init_tab2()

    def rebuild_tab3(self):
        self.tab3.deleteLater()
        self.tab3 = QWidget()
        self.tabs.insertTab(2, self.tab3, self.config.translations[self.language]["tab3"])
        self.init_tab3()

    def get_language_text(self, text: str) -> str:
        if " / " in text:
            parts = text.split(" / ")
            return parts[0] if self.language == "Deutsch" else parts[1]
        return text

    def find_key_by_language_text(self, category: str, value: str) -> Optional[str]:
        """Findet den zweisprachigen Schlüssel in einer Kategorie basierend auf dem sprachspezifischen Wert."""
        for key in self.config.options[category].keys():
            if self.get_language_text(key) == value:
                return key
        return None

    def populate_options(self):
        defaults = self.config.options["defaults"]
        
        self.location_combo.setCurrentText(self.config.translations[self.language][defaults["location"]])
        self.update_location_options(self.location_combo.currentText())
        
        self.type_combo.addItems([self.get_language_text(item) for item in self.config.options["portrait_types"]])
        self.type_combo.setCurrentText(self.get_language_text(defaults["type"]))
        self.type_include.setCurrentText(self.config.translations[self.language][defaults["type_include"]])
        
        self.success_combo.addItems([self.get_language_text(item) for item in self.config.options["success_levels"]])
        self.success_combo.setCurrentText(self.get_language_text(defaults["success"]))
        self.success_include.setCurrentText(self.config.translations[self.language][defaults["success_include"]])
        
        self.nationality_input.setText(defaults["nationality"])
        self.nationality_include.setCurrentText(self.config.translations[self.language][defaults["nationality_include"]])
        
        self.role_combo.addItems([self.get_language_text(item) for item in self.config.options["roles"]])
        self.role_combo.setCurrentText(self.get_language_text(defaults["role"]))
        self.role_include.setCurrentText(self.config.translations[self.language][defaults["role_include"]])
        
        self.gender_combo.setCurrentText(defaults["gender"] if self.language == "Deutsch" else "Male" if defaults["gender"] == "Männlich" else "Female")
        
        self.age_combo.addItems([self.get_language_text(item) for item in self.config.options["age_range"]])
        self.age_combo.setCurrentText(self.get_language_text(defaults["age_range"]))
        self.age_include.setCurrentText(self.config.translations[self.language][defaults["age_include"]])
        
        self.camera_type_combo.addItems([self.get_language_text(item) for item in self.config.options["camera_types_by_portrait_type"][defaults["type"]]])
        self.camera_type_combo.setCurrentText(self.get_language_text(defaults["camera_type"]))
        self.camera_type_include.setCurrentText(self.config.translations[self.language][defaults["camera_type_include"]])
        self.update_camera_options(self.camera_type_combo.currentText())
        
        self.camera_combo.setCurrentText(defaults["camera"])
        self.camera_include.setCurrentText(self.config.translations[self.language][defaults["camera_include"]])
        
        self.lens_combo.setCurrentText(self.get_language_text(defaults["lens"]))
        self.lens_include.setCurrentText(self.config.translations[self.language][defaults["lens_include"]])
        
        self.film_combo.setCurrentText(self.get_language_text(defaults["film"]))
        self.film_include.setCurrentText(self.config.translations[self.language][defaults["film_include"]])
        
        self.film_detail_combo.addItems([self.get_language_text(item) for item in self.config.options["film_details"]])
        self.film_detail_combo.setCurrentText(self.get_language_text(defaults["film_detail"]))
        self.film_detail_include.setCurrentText(self.config.translations[self.language][defaults["film_detail_include"]])
        
        self.quality_combo.addItems([self.get_language_text(item) for item in self.config.options["quality_levels"]])
        self.quality_combo.setCurrentText(self.get_language_text(defaults["quality"]))
        self.quality_include.setCurrentText(self.config.translations[self.language][defaults["quality_include"]])
        
        self.subject_combo.addItems([self.get_language_text(item) for item in self.config.options["subject_traits"]])
        self.subject_combo.setCurrentText(self.get_language_text(defaults["traits"]))
        self.subject_include.setCurrentText(self.config.translations[self.language][defaults["traits_include"]])
        
        self.subject_detail_combo.addItems([self.get_language_text(item) for item in self.config.options["subject_details"]])
        self.subject_detail_combo.setCurrentText(self.get_language_text(defaults["details"]))
        self.subject_detail_include.setCurrentText(self.config.translations[self.language][defaults["details_include"]])
        
        self.style_combo.addItems([self.get_language_text(item) for item in self.config.options["styles"]])
        self.style_combo.setCurrentText(self.get_language_text(defaults["style"]))
        self.style_include.setCurrentText(self.config.translations[self.language][defaults["style_include"]])
        
        self.update_clothing_options(self.gender_combo.currentText())
        self.clothing_combo.setCurrentText(self.get_language_text(defaults["clothing"]))
        self.clothing_include.setCurrentText(self.config.translations[self.language][defaults["clothing_include"]])
        
        self.cultural_combo.addItems([self.get_language_text(item) for item in self.config.options["cultural_elements"]])
        self.cultural_combo.setCurrentText(self.get_language_text(defaults["cultural_element"]))
        self.cultural_include.setCurrentText(self.config.translations[self.language][defaults["cultural_include"]])
        
        self.time_period_combo.addItems([self.get_language_text(item) for item in self.config.options["time_periods"]])
        self.time_period_combo.setCurrentText(self.get_language_text(defaults["time_period"]))
        self.time_period_include.setCurrentText(self.config.translations[self.language][defaults["time_period_include"]])
        
        self.pose_combo.addItems([self.get_language_text(item) for item in self.config.options["poses"]])
        self.pose_combo.setCurrentText(self.get_language_text(defaults["pose"]))
        self.pose_include.setCurrentText(self.config.translations[self.language][defaults["pose_include"]])
        
        self.lighting_combo.addItems([self.get_language_text(item) for item in self.config.options["lighting"]])
        self.lighting_combo.setCurrentText(self.get_language_text(defaults["lighting"]))
        self.lighting_include.setCurrentText(self.config.translations[self.language][defaults["lighting_include"]])
        
        self.background_combo.addItems([self.get_language_text(item) for item in self.config.options["backgrounds"]])
        self.background_combo.setCurrentText(self.get_language_text(defaults["background"]))
        self.background_include.setCurrentText(self.config.translations[self.language][defaults["background_include"]])
        
        self.props_combo.addItems([self.get_language_text(item) for item in self.config.options["props"]])
        self.props_combo.setCurrentText(self.get_language_text(defaults["prop"]))
        self.props_include.setCurrentText(self.config.translations[self.language][defaults["prop_include"]])
        
        self.ambiance_combo.addItems([self.get_language_text(item) for item in self.config.options["ambiance"]])
        self.ambiance_combo.setCurrentText(self.get_language_text(defaults["ambiance"]))
        self.ambiance_include.setCurrentText(self.config.translations[self.language][defaults["ambiance_include"]])
        
        self.weather_combo.addItems([self.get_language_text(item) for item in self.config.options["weather_conditions"]])
        self.weather_combo.setCurrentText(self.get_language_text(defaults["weather"]))
        self.weather_include.setCurrentText(self.config.translations[self.language][defaults["weather_include"]])
        
        self.emotion_combo.addItems([self.get_language_text(item) for item in self.config.options["emotional_depth"]])
        self.emotion_combo.setCurrentText(self.get_language_text(defaults["emotion"]))
        self.emotion_include.setCurrentText(self.config.translations[self.language][defaults["emotion_include"]])
        
        self.post_processing_choice_combo.setCurrentText(self.config.translations[self.language][defaults["post_processing_choice"]])
        self.update_post_processing_options(self.post_processing_choice_combo.currentText())
        self.post_processing_combo.setCurrentText(self.get_language_text(defaults["post_processing"]))
        self.post_processing_include.setCurrentText(self.config.translations[self.language][defaults["post_processing_include"]])
        
        self.effect_combo.addItems([self.get_language_text(item) for item in self.config.options["effects"]])
        self.effect_combo.setCurrentText(self.get_language_text(defaults["effect"]))
        self.effect_include.setCurrentText(self.config.translations[self.language][defaults["effect_include"]])
        
        self.negative_prompt_input.setText(defaults["negative_prompt"])
        
        self.update_prompt_preview()

    def update_location_options(self, location: str):
        is_outdoor = location == self.config.translations[self.language]["outdoor"]
        self.weather_combo.setEnabled(is_outdoor)
        self.weather_include.setEnabled(is_outdoor)
        self.update_type_options(self.type_combo.currentText())

    def update_type_options(self, portrait_type: str):
        self.camera_type_combo.clear()
        for key in self.config.options["camera_types_by_portrait_type"].keys():
            if self.get_language_text(key) == portrait_type:
                camera_types = self.config.options["camera_types_by_portrait_type"][key]
                break
        else:
            camera_types = []
        self.camera_type_combo.addItems([self.get_language_text(item) for item in camera_types])
        if self.camera_type_combo.count() > 0:
            self.camera_type_combo.setCurrentText(self.camera_type_combo.itemText(0))
            self.update_camera_options(self.camera_type_combo.currentText())

    def update_camera_options(self, camera_type: str):
        if not camera_type:
            return
        camera_key = self.find_key_by_language_text("cameras", camera_type)
        if not camera_key:
            return
        
        self.camera_combo.clear()
        self.camera_combo.addItems(self.config.options["cameras"][camera_key])
        
        self.lens_combo.clear()
        if camera_key in self.config.options["lenses"]:
            self.lens_combo.addItems([self.get_language_text(item) for item in self.config.options["lenses"][camera_key]])
        else:
            self.lens_combo.addItems(["Keine Linsen verfügbar" if self.language == "Deutsch" else "No lenses available"])
        
        self.film_combo.clear()
        portrait_type = self.type_combo.currentText()
        if portrait_type == self.get_language_text("Schwarz-Weiß / Black-and-White"):
            if camera_key in self.config.options["films"]:
                self.film_combo.addItems([self.get_language_text(item) for item in self.config.options["films"][camera_key]])
            else:
                self.film_combo.addItems(["Kein Film verfügbar" if self.language == "Deutsch" else "No film available"])
        elif portrait_type == self.get_language_text("C41 (Farbe) / C41 (Color)"):
            self.film_combo.addItems([self.get_language_text(item) for item in self.config.options["films"]["c41"]])
        elif portrait_type == self.get_language_text("E6 (Dias) / E6 (Slides)"):
            self.film_combo.addItems([self.get_language_text(item) for item in self.config.options["films"]["e6"]])
        elif portrait_type == self.get_language_text("Polaroid / Polaroid"):
            self.film_combo.addItems([self.get_language_text(item) for item in self.config.options["films"]["Polaroid"]])
        elif portrait_type == self.get_language_text("Expired / Expired"):
            self.film_combo.addItems([self.get_language_text(item) for item in self.config.options["films"]["expired"]])
        elif portrait_type == self.get_language_text("Experimental / Experimental"):
            self.film_combo.addItems([self.get_language_text(item) for item in self.config.options["films"]["experimental"]])
        self.update_prompt_preview()

    def update_clothing_options(self, gender: str):
        self.clothing_combo.clear()
        if gender in ["Male", "Männlich"]:
            self.clothing_combo.addItems([self.get_language_text(item) for item in self.config.options["mens_clothing"]])
        else:
            self.clothing_combo.addItems([self.get_language_text(item) for item in self.config.options["womens_clothing"]])
        self.update_prompt_preview()

    def update_post_processing_options(self, choice: str):
        self.post_processing_combo.clear()
        if choice == self.config.translations[self.language]["yes"]:
            self.post_processing_combo.addItems([self.get_language_text(item) for item in self.config.options["post_processing"][1:]])
        else:
            self.post_processing_combo.addItems([self.get_language_text(self.config.options["post_processing"][0])])
        self.update_prompt_preview()

    def update_prompt_preview(self):
        required_combos = [
            self.success_combo, self.role_combo, self.age_combo, self.camera_combo,
            self.lens_combo, self.film_combo, self.film_detail_combo, self.quality_combo,
            self.subject_combo, self.subject_detail_combo, self.style_combo, self.clothing_combo,
            self.cultural_combo, self.time_period_combo, self.pose_combo, self.lighting_combo,
            self.background_combo, self.props_combo, self.ambiance_combo, self.weather_combo,
            self.emotion_combo, self.post_processing_combo, self.effect_combo
        ]
        if any(not combo.count() for combo in required_combos):
            self.preview_text.setText("Bitte warte, bis alle Optionen geladen sind...")
            return

        location = self.location_combo.currentText()
        portrait_type = self.type_combo.currentText()
        is_outdoor = location == self.config.translations[self.language]["outdoor"]
        prefix = (self.config.translations[self.language]["prompt_prefix_outdoor_bw"] if is_outdoor else self.config.translations[self.language]["prompt_prefix_bw"]) if portrait_type == self.get_language_text("Schwarz-Weiß / Black-and-White") else (self.config.translations[self.language]["prompt_prefix_outdoor_color"] if is_outdoor else self.config.translations[self.language]["prompt_prefix_color"])
        prompt_parts = [prefix]
        
        # Geschlecht immer hinzufügen
        gender = self.gender_combo.currentText()
        prompt_parts.append(gender)
        
        if self.success_include.currentText() == self.config.translations[self.language]["yes"]:
            prompt_parts.append(self.success_combo.currentText())
        if self.nationality_include.currentText() == self.config.translations[self.language]["yes"]:
            nationality = self.nationality_input.text().strip() or "undefined"
            prompt_parts.append(nationality)
        if self.role_include.currentText() == self.config.translations[self.language]["yes"]:
            prompt_parts.append(self.role_combo.currentText())
        
        base = " ".join(prompt_parts)
        if len(prompt_parts) > 1:
            base = f"{prefix} {self.config.translations[self.language]['prompt_of']} {base}"

        details = []
        if self.age_include.currentText() == self.config.translations[self.language]["yes"]:
            details.append(self.age_combo.currentText())
        if self.subject_include.currentText() == self.config.translations[self.language]["yes"]:
            details.append(self.subject_combo.currentText())
        if self.subject_detail_include.currentText() == self.config.translations[self.language]["yes"]:
            details.append(self.subject_detail_combo.currentText())
        if self.pose_include.currentText() == self.config.translations[self.language]["yes"]:
            details.append(self.pose_combo.currentText())
        if details:
            base += f", {', '.join(details)}"

        tech = []
        if self.camera_include.currentText() == self.config.translations[self.language]["yes"]:
            tech.append(self.camera_combo.currentText())
        if self.lens_include.currentText() == self.config.translations[self.language]["yes"]:
            tech.append(self.lens_combo.currentText())
        if tech:
            base += f", {self.config.translations[self.language]['prompt_captured_with']} {' '.join(tech)}"
        if self.film_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f" {self.config.translations[self.language]['prompt_on']} {self.film_combo.currentText()}"
        if self.film_detail_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f", {self.film_detail_combo.currentText()}"
        if self.quality_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f", {self.quality_combo.currentText()}"

        if self.style_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f". Stil: {self.style_combo.currentText()}"

        clothing = []
        if self.clothing_include.currentText() == self.config.translations[self.language]["yes"]:
            clothing.append(self.clothing_combo.currentText())
        if self.cultural_include.currentText() == self.config.translations[self.language]["yes"]:
            clothing.append(self.cultural_combo.currentText())
        if clothing:
            join_word = "und" if self.language == "Deutsch" else "and"
            base += f". {self.config.translations[self.language]['prompt_wearing']} {join_word.join(clothing)}"

        if self.time_period_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f", {self.config.translations[self.language]['prompt_in']} {self.time_period_combo.currentText()}"
        if self.lighting_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f", {self.lighting_combo.currentText()}"
        if self.background_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f". Hintergrund: {self.background_combo.currentText()}"
        if self.props_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f". Requisite: {self.props_combo.currentText()}"
        if self.ambiance_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f". Atmosphäre: {self.ambiance_combo.currentText()}"
        if is_outdoor and self.weather_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f". {self.weather_combo.currentText()}"
        if self.emotion_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f". Ausdruck: {self.emotion_combo.currentText()}"
        if self.post_processing_include.currentText() == self.config.translations[self.language]["yes"] and self.post_processing_choice_combo.currentText() == self.config.translations[self.language]["yes"]:
            base += f". {self.config.translations[self.language]['prompt_post_processed']} {self.post_processing_combo.currentText()}"
        if self.effect_include.currentText() == self.config.translations[self.language]["yes"]:
            base += f". Gesamteffekt: {self.effect_combo.currentText()}"

        negative_prompt = self.negative_prompt_input.text().strip()
        if negative_prompt:
            full_prompt = f"{base}\n\n{self.config.translations[self.language]['prompt_negative']} {negative_prompt}"
        else:
            full_prompt = base

        self.preview_text.setText(full_prompt)

    def generate_prompt(self):
        self.prompt_text.setText(self.preview_text.toPlainText())
        self.tabs.setCurrentIndex(1)

    def save_edited_prompt(self):
        prompt = self.prompt_text.toPlainText()
        with open("generated_prompt.json", "w", encoding="utf-8") as f:
            json.dump({"prompt": prompt}, f, indent=4)

    def add_option(self, category: str, new_option: str, subcategory: Optional[str] = None):
        if new_option:
            if category in ["cameras", "films", "lenses"] and subcategory:
                self.config.options[category][subcategory].append(new_option)
            else:
                self.config.options[category].append(new_option)
            self.rebuild_tab3()
            self.populate_options()

    def save_options(self):
        with open(self.config.options_file, "w", encoding="utf-8") as f:
            json.dump(self.config.options, f, indent=4)

if __name__ == "__main__":
    app = QApplication(sys.argv)
    window = PortraitGenerator()
    window.show()
    sys.exit(app.exec())